@@ -1,12 +1,12 @@
 /*
- *  $Id: defLoad.c,v 4.1 2005/01/01 00:12:33 bkorb Exp $
+ *  $Id: defLoad.c,v 4.4 2005/01/24 00:00:32 bkorb Exp $
  *  This module loads the definitions, calls yyparse to decipher them,
  *  and then makes a fixup pass to point all children definitions to
  *  their parent definition.
  */
 
 /*
- *  AutoGen copyright 1992-2004 Bruce Korb
+ *  AutoGen copyright 1992-2005 Bruce Korb
  *
  *  AutoGen is free software.
  *  You may redistribute it and/or modify it under the terms of the
@@ -25,15 +25,21 @@
  *             Boston,  MA  02111-1307, USA.
  */
 
-STATIC tDefEntry* pFreeEntryList = NULL;
-STATIC void*      pAllocList     = NULL;
+static tDefEntry* pFreeEntryList = NULL;
+static void*      pAllocList     = NULL;
 
 #define ENTRY_SPACE        (4096 - sizeof(void*))
 #define ENTRY_ALLOC_CT     (ENTRY_SPACE / sizeof(tDefEntry))
 #define ENTRY_ALLOC_SIZE   \
     ((ENTRY_ALLOC_CT * sizeof( tDefEntry )) + sizeof(void*))
 
-EXPORT void
+/* = = = START-STATIC-FORWARD = = = */
+/* static forward declarations maintained by :mkfwd */
+static tDefEntry*
+insertDef( tDefEntry* pDef );
+/* = = = END-STATIC-FORWARD = = = */
+
+LOCAL void
 freeEntry( tDefEntry* pDE )
 {
     pDE->pNext = pFreeEntryList;
@@ -41,7 +47,7 @@ freeEntry( tDefEntry* pDE )
 }
 
 
-EXPORT tDefEntry*
+LOCAL tDefEntry*
 getEntry( void )
 {
     tDefEntry*  pRes = pFreeEntryList;
@@ -88,7 +94,7 @@ getEntry( void )
 /*
  *  Append a new entry at the end of a sibling (or twin) list.
  */
-STATIC tDefEntry*
+static tDefEntry*
 insertDef( tDefEntry* pDef )
 {
     tDefEntry* pList = ppParseStack[ stackDepth ];
@@ -198,7 +204,7 @@ insertDef( tDefEntry* pDef )
 }
 
 
-EXPORT tDefEntry*
+LOCAL tDefEntry*
 findPlace( char* name, tCC* pzIndex )
 {
     tDefEntry* pE = getEntry();
@@ -219,7 +225,9 @@ findPlace( char* name, tCC* pzIndex )
     }
 
     strtransform( pE->pzDefName, pE->pzDefName );
-    pE->valType   = VALTYP_UNKNOWN;
+    pE->valType     = VALTYP_UNKNOWN;
+    pE->pzSrcFile   = (char*)pCurCtx->pzCtxFname;
+    pE->srcLineNum  = pCurCtx->lineNo;
     return (pCurrentEntry = insertDef( pE ));
 }
 
@@ -228,7 +236,7 @@ findPlace( char* name, tCC* pzIndex )
  *
  *  Suck in the entire definitions file and parse it.
  */
-EXPORT void
+LOCAL void
 readDefines( void )
 {
     char*    pzData;
@@ -241,7 +249,7 @@ readDefines( void )
         pBaseCtx = (tScanCtx*)AGALOC( sizeof( tScanCtx ), "scan context" );
         memset( (void*)pBaseCtx, 0, sizeof( tScanCtx ));
         pBaseCtx->lineNo     = 1;
-        pBaseCtx->pzFileName = "@@ No-Definitions @@";
+        pBaseCtx->pzCtxFname = "@@ No-Definitions @@";
         return;
     }
 
@@ -392,7 +400,7 @@ readDefines( void )
         AG_ABEND( "No definition data were read" );
 
     *pzData = NUL;
-    AGDUPSTR( pBaseCtx->pzFileName, OPT_ARG( DEFINITIONS ), "def file name" );
+    AGDUPSTR( pBaseCtx->pzCtxFname, OPT_ARG( DEFINITIONS ), "def file name" );
 
     /*
      *  Close the input file, parse the data
@@ -406,7 +414,7 @@ readDefines( void )
 }
 
 
-extern void
+void
 unloadDefs( void )
 {
 }
