@@ -1,12 +1,12 @@
 
 /*
- *  $Id: expGuile.c,v 1.33 2003/05/22 04:14:15 bkorb Exp $
+ *  $Id: expGuile.c,v 4.3 2005/01/24 00:00:32 bkorb Exp $
  *  This module implements the expression functions that should
  *  be part of Guile.
  */
 
 /*
- *  AutoGen copyright 1992-2003 Bruce Korb
+ *  AutoGen copyright 1992-2005 Bruce Korb
  *
  *  AutoGen is free software.
  *  You may redistribute it and/or modify it under the terms of the
@@ -25,7 +25,7 @@
  *             Boston,  MA  02111-1307, USA.
  */
 
-teGuileType
+LOCAL teGuileType
 gh_type_e( SCM typ )
 {
     if (gh_boolean_p( typ ))
@@ -64,7 +64,7 @@ gh_type_e( SCM typ )
     return GH_TYPE_UNDEFINED;
 }
 
-EXPORT SCM
+LOCAL SCM
 ag_scm_c_eval_string_from_file_line( tCC* pzExpr, tCC* pzFile, int line )
 {
     SCM port;
