@@ -1,13 +1,13 @@
 
 /*
  *  expState.c
- *  $Id: expState.c,v 1.53 2004/08/15 17:01:34 bkorb Exp $
+ *  $Id: expState.c,v 4.5 2005/01/24 00:00:32 bkorb Exp $
  *  This module implements expression functions that
  *  query and get state information from AutoGen data.
  */
 
 /*
- *  AutoGen copyright 1992-2004 Bruce Korb
+ *  AutoGen copyright 1992-2005 Bruce Korb
  *
  *  AutoGen is free software.
  *  You may redistribute it and/or modify it under the terms of the
@@ -26,14 +26,23 @@
  *             Boston,  MA  02111-1307, USA.
  */
 
-STATIC int     entry_length(   char* pzName );
-STATIC int     count_entries(  char* pzName );
+/* = = = START-STATIC-FORWARD = = = */
+/* static forward declarations maintained by :mkfwd */
+static int
+entry_length( char* pzName );
+
+static int
+count_entries( char* pzName );
+
+static SCM
+find_entry_value( SCM op, SCM obj, SCM test );
+/* = = = END-STATIC-FORWARD = = = */
 
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
  *  EXPRESSION EVALUATION SUPPORT ROUTINES
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
-STATIC int
+static int
 entry_length( char* pzName )
 {
     tDefEntry**  papDefs = findEntryList( pzName );
@@ -55,7 +64,7 @@ entry_length( char* pzName )
 }
 
 
-STATIC int
+static int
 count_entries( char* pzName )
 {
     tDefEntry**  papDefs = findEntryList( pzName );
@@ -74,7 +83,7 @@ count_entries( char* pzName )
 }
 
 
-STATIC SCM
+static SCM
 find_entry_value( SCM op, SCM obj, SCM test )
 {
     ag_bool     isIndexed;
@@ -254,7 +263,7 @@ ag_scm_count( SCM obj )
 SCM
 ag_scm_def_file( void )
 {
-    return gh_str02scm( (char*)(void*)pBaseCtx->pzFileName );
+    return gh_str02scm( (char*)(void*)pBaseCtx->pzCtxFname );
 }
 
 
@@ -537,18 +546,24 @@ ag_scm_tpl_file( SCM full )
 
 /*=gfunc tpl_file_line
  *
- * what:   get the template file and line number
+ * what:   get the template file+line number
  *
  * exparg: msg-fmt, formatting for line message, optional
  *
  * doc:
  *
- *  Returns the file and line number of the current template macro using either
- *  the default format, "from %s line %d", or else the format you supply.
- *  For example, if you want to insert a "C" language file-line directive,
- *  you would supply the format "# %2$d %1$s".  With the current version of
- *  AutoGen, it is even safe to use the formatting string, "%2$d".  AutoGen
- *  uses an argument vector version of printf:  @xref{snprintfv}.
+ *  Returns the file and line number of the current template macro using
+ *  either the default format, "from %s line %d", or else the format you
+ *  supply.  For example, if you want to insert a "C" language file-line
+ *  directive, you would supply the format "# %2$d \"%1$s\"", but that
+ *  is also already supplied with the scheme variable
+ *  @xref{SCM c-file-line-fmt}.  You may use it thus:
+ *  @example
+ *  (tpl-file-line c-file-line-fmt)
+ *  @end example
+ *
+ *  It is also safe to use the formatting string, "%2$d".  AutoGen uses
+ *  an argument vector version of printf: @xref{snprintfv}.
 =*/
 SCM
 ag_scm_tpl_file_line( SCM fmt )
@@ -572,7 +587,7 @@ ag_scm_tpl_file_line( SCM fmt )
     {
         void* args[2];
         args[0] = (void*)pCurTemplate->pzFileName;
-        args[1] = (void*)pCurMacro->lineNo;
+        args[1] = (void*)(long)pCurMacro->lineNo;
         sprintfv( pz, pzFmt, (snv_constpointer*)args  );
     }
 
@@ -584,6 +599,76 @@ ag_scm_tpl_file_line( SCM fmt )
         return res;
     }
 }
+
+
+/*=gfunc def_file_line
+ *
+ * what:   get a definition file+line number
+ *
+ * exparg: ag-name, name of AutoGen value
+ * exparg: msg-fmt, formatting for line message, optional
+ *
+ * doc:
+ *
+ *  Returns the file and line number of a AutoGen defined value, using
+ *  either the default format, "from %s line %d", or else the format you
+ *  supply.  For example, if you want to insert a "C" language file-line
+ *  directive, you would supply the format "# %2$d \"%1$s\"", but that
+ *  is also already supplied with the scheme variable
+ *  @xref{SCM c-file-line-fmt}.  You may use it thus:
+ *
+ *  @example
+ *  (def-file-line "ag-def-name" c-file-line-fmt)
+ *  @end example
+ *
+ *  It is also safe to use the formatting string, "%2$d".  AutoGen uses
+ *  an argument vector version of printf: @xref{snprintfv}.
+=*/
+SCM
+ag_scm_def_file_line( SCM obj, SCM fmt )
+{
+    tSCC    zFmt[]  = "from %s line %d";
+    tCC*    pzFmt   = zFmt;
+    char    zScribble[ 1024 ];
+    char*   pzScrib = zScribble;
+
+    tDefEntry*  pE;
+    ag_bool     x;
+
+    pE = findDefEntry( ag_scm2zchars( obj, "ag value" ), &x );
+
+    /*
+     *  IF we did not find the entry we are looking for
+     *  THEN return UNDEFINED
+     */
+    if (pE == NULL)
+        return SCM_UNDEFINED;
+
+    if (gh_string_p( fmt ))
+        pzFmt = ag_scm2zchars( fmt, "file/line format" );
+
+    {
+        size_t  maxlen = strlen( pE->pzSrcFile )
+                       + strlen( pzFmt ) + 4 * sizeof( int );
+        if (maxlen >= sizeof( zScribble ))
+            pzScrib = (char*)AGALOC( maxlen, "file-line buffer" );
+    }
+
+    {
+        void* args[2];
+        args[0] = (void*)pE->pzSrcFile;
+        args[1] = (void*)(long)pE->srcLineNum;
+        sprintfv( pzScrib, pzFmt, (snv_constpointer*)args  );
+    }
+
+    {
+        SCM res = gh_str02scm( pzScrib );
+        if (pzScrib != zScribble)
+            AGFREE( (void*)pzScrib );
+
+        return res;
+    }
+}
 /*
  * Local Variables:
  * mode: C
