@@ -1,7 +1,7 @@
 /* -*- buffer-read-only: t -*- vi: set ro:
  *
  * Prototypes for agen5
- * Generated Sat Feb  5 08:27:44 PST 2005
+ * Generated Sun Apr 24 17:48:42 PDT 2005
  */
 #ifndef AGEN5_PROTO_H_GUARD
 #define AGEN5_PROTO_H_GUARD
@@ -58,9 +58,6 @@ doOptions( int arg_ct, char** arg_vec );
 LOCAL tCC*
 getDefine( tCC* pzDefName );
 
-LOCAL unsigned int
-doEscapeChar( tCC* pzIn, char* pRes );
-
 LOCAL char*
 spanQuote( char* pzQte );
 
